apk-user-cert
============================================================
.. code:: sh

  $ pip install apk-user-cert

###############
USAGE
###############
.. code:: sh

  $ apk-user-cert sample.apk
    Decompiling ...
    networkSecurityConfig attrib not founded
    network_security_config.xml not founded
    Rebuilding ...
    ./sample/dist/sample.apk


